Installation
============

Requirements
------------

pytest-selenium will work with Python >=3.6.

Install pytest-selenium
-----------------------

To install pytest-selenium using `pip <https://pip.pypa.io/>`_:

.. code-block:: bash

  $ pip install pytest-selenium

To install from source:

.. code-block:: bash

  $ python setup.py develop

Optional packages
-----------------

Appium
~~~~~~
To install pytest-selenium with `Appium <https://appium.io/>`_ support:

.. code-block:: bash

  $ pip install pytest-selenium[appium]
